import { Position, Point, Geometry, FeatureWithProps } from "../utils/geojson-types.js";
export type ScreenCoordinates = [number, number];
export type EditAction<TData> = {
    updatedData: TData;
    editType: string;
    editContext: any;
};
export type Pick = {
    index: number;
    object?: any;
    isGuide?: boolean;
    featureIndex?: number;
    type?: string;
    isEditingHandle?: boolean | null;
};
export type Viewport = {
    width: number;
    height: number;
    longitude: number;
    latitude: number;
    zoom: number;
    bearing?: number;
    pitch?: number;
};
export type BasePointerEvent = {
    picks: Pick[];
    screenCoords: ScreenCoordinates;
    mapCoords: Position;
    sourceEvent: any;
};
export type ClickEvent = BasePointerEvent;
export type StartDraggingEvent = BasePointerEvent & {
    pointerDownPicks?: Pick[] | null;
    pointerDownScreenCoords: ScreenCoordinates;
    pointerDownMapCoords: Position;
    cancelPan: () => void;
};
export type StopDraggingEvent = BasePointerEvent & {
    pointerDownPicks?: Pick[] | null;
    pointerDownScreenCoords: ScreenCoordinates;
    pointerDownMapCoords: Position;
};
export type DraggingEvent = BasePointerEvent & {
    pointerDownPicks?: Pick[] | null;
    pointerDownScreenCoords: ScreenCoordinates;
    pointerDownMapCoords: Position;
    cancelPan: () => void;
};
export type PointerMoveEvent = BasePointerEvent & {
    pointerDownPicks?: Pick[] | null;
    pointerDownScreenCoords?: ScreenCoordinates | null;
    pointerDownMapCoords?: Position | null;
    cancelPan: () => void;
    isDragging?: boolean;
};
export type Tooltip = {
    position: Position;
    text: string;
};
export type EditHandleType = 'existing' | 'intermediate' | 'snap-source' | 'snap-target' | 'scale' | 'rotate';
export type EditHandleFeature = FeatureWithProps<Point, {
    guideType: 'editHandle';
    editHandleType: EditHandleType;
    featureIndex: number;
    positionIndexes?: number[];
    shape?: string;
}>;
export type TentativeFeature = FeatureWithProps<Geometry, {
    guideType: 'tentative';
    shape?: string;
}>;
export type GuideFeature = EditHandleFeature | TentativeFeature;
export type GuideFeatureCollection = {
    type: 'FeatureCollection';
    features: Readonly<GuideFeature>[];
    properties?: {};
};
export type ModeProps<TData> = {
    data: TData;
    modeConfig: any;
    selectedIndexes: number[];
    cursor: string | null | undefined;
    lastPointerMoveEvent: PointerMoveEvent;
    onEdit: (editAction: EditAction<TData>) => void;
    onUpdateCursor: (cursor: string | null | undefined) => void;
};
//# sourceMappingURL=types.d.ts.map