import type { UpdateParameters, DefaultProps } from '@deck.gl/core';
import { GeoJsonLayer, TextLayer } from '@deck.gl/layers';
import { EditAction, ClickEvent, StartDraggingEvent, StopDraggingEvent, DraggingEvent, PointerMoveEvent } from "../edit-modes/types.js";
import { GeoJsonEditModeType } from "../edit-modes/geojson-edit-mode.js";
import { Color } from "../utils/types.js";
import { EditableLayer, EditableLayerProps } from "./editable-layer.js";
import { Feature, FeatureCollection } from "../utils/geojson-types.js";
export type EditableGeojsonLayerProps<DataT = any> = EditableLayerProps & {
    data: DataT;
    mode?: any;
    modeConfig?: any;
    selectedFeatureIndexes?: number[];
    onEdit?: (updatedData?: any, editType?: string, featureIndexes?: number[], editContext?: any) => void;
    pickable?: boolean;
    pickingRadius?: number;
    pickingDepth?: number;
    fp64?: boolean;
    filled?: boolean;
    stroked?: boolean;
    lineWidthScale?: number;
    lineWidthMinPixels?: number;
    lineWidthMaxPixels?: number;
    pickingLineWidthExtraPixels?: number;
    lineWidthUnits?: string;
    lineJointRounded?: boolean;
    lineCapRounded?: boolean;
    lineMiterLimit?: number;
    pointRadiusScale?: number;
    pointRadiusMinPixels?: number;
    pointRadiusMaxPixels?: number;
    getLineColor?: Color | ((feature: any, isSelected: any, mode: any) => Color);
    getFillColor?: Color | ((feature: any, isSelected: any, mode: any) => Color);
    getRadius?: number | ((f: any) => number);
    getLineWidth?: number | ((f: any) => number);
    getTentativeLineColor?: Color | ((feature: any, isSelected: any, mode: any) => Color);
    getTentativeFillColor?: Color | ((feature: any, isSelected: any, mode: any) => Color);
    getTentativeLineWidth?: number | ((f: any) => number);
    editHandleType?: string;
    editHandlePointRadiusScale?: number;
    editHandlePointOutline?: boolean;
    editHandlePointStrokeWidth?: number;
    editHandlePointRadiusUnits?: string;
    editHandlePointRadiusMinPixels?: number;
    editHandlePointRadiusMaxPixels?: number;
    getEditHandlePointColor?: Color | ((handle: any) => Color);
    getEditHandlePointOutlineColor?: Color | ((handle: any) => Color);
    getEditHandlePointRadius?: number | ((handle: any) => number);
    editHandleIconAtlas?: any;
    editHandleIconMapping?: any;
    editHandleIconSizeScale?: number;
    editHandleIconSizeUnits?: string;
    getEditHandleIcon?: (handle: any) => string;
    getEditHandleIconSize?: number;
    getEditHandleIconColor?: Color | ((handle: any) => Color);
    getEditHandleIconAngle?: number | ((handle: any) => number);
    billboard?: boolean;
};
export declare class EditableGeoJsonLayer extends EditableLayer<FeatureCollection, EditableGeojsonLayerProps<FeatureCollection>> {
    static layerName: string;
    static defaultProps: DefaultProps<EditableGeojsonLayerProps<any>>;
    state: EditableLayer['state'] & {
        cursor?: 'grabbing' | 'grab' | null;
        mode: GeoJsonEditModeType;
        lastPointerMoveEvent: PointerMoveEvent;
        tentativeFeature?: Feature;
        editHandles: any[];
        selectedFeatures: Feature[];
    };
    renderLayers(): any;
    initializeState(): void;
    shouldUpdateState(opts: any): any;
    updateState({ props, oldProps, changeFlags, context }: UpdateParameters<this>): void;
    getModeProps(props: EditableGeojsonLayerProps<any>): {
        modeConfig: any;
        data: any;
        selectedIndexes: number[];
        lastPointerMoveEvent: PointerMoveEvent;
        cursor: "grabbing" | "grab";
        onEdit: (editAction: EditAction<FeatureCollection>) => void;
        onUpdateCursor: (cursor: string | null | undefined) => void;
    };
    selectionAwareAccessor(accessor: any): any;
    isFeatureSelected(feature: Feature): boolean;
    getPickingInfo({ info, sourceLayer }: Record<string, any>): any;
    _updateAutoHighlight(info: any): void;
    createGuidesLayers(): GeoJsonLayer<any, {}>[];
    createTooltipsLayers(): TextLayer<any, {}>[];
    onLayerClick(event: ClickEvent): void;
    onLayerKeyUp(event: KeyboardEvent): void;
    onStartDragging(event: StartDraggingEvent): void;
    onDragging(event: DraggingEvent): void;
    onStopDragging(event: StopDraggingEvent): void;
    onPointerMove(event: PointerMoveEvent): void;
    getCursor({ isDragging }: {
        isDragging: boolean;
    }): null | 'grabbing' | 'grab';
    getActiveMode(): GeoJsonEditModeType;
}
//# sourceMappingURL=editable-geojson-layer.d.ts.map