import { CompositeLayer, CompositeLayerProps } from '@deck.gl/core';
import { DraggingEvent, ClickEvent, StartDraggingEvent, StopDraggingEvent, PointerMoveEvent } from "../edit-modes/types.js";
import { Position } from "../utils/geojson-types.js";
export type EditableLayerProps<DataType = any> = CompositeLayerProps & {
    pickingRadius?: number;
    pickingDepth?: number;
};
export declare abstract class EditableLayer<DataT = any, ExtraPropsT = Record<string, unknown>> extends CompositeLayer<ExtraPropsT & Required<EditableLayerProps<DataT>>> {
    static layerName: string;
    state: {
        _editableLayerState: any;
    };
    onLayerClick(event: ClickEvent): void;
    onStartDragging(event: StartDraggingEvent): void;
    onStopDragging(event: StopDraggingEvent): void;
    onDragging(event: DraggingEvent): void;
    onPointerMove(event: PointerMoveEvent): void;
    onLayerKeyUp(event: KeyboardEvent): void;
    initializeState(): void;
    finalizeState(): void;
    _addEventHandlers(): void;
    _removeEventHandlers(): void;
    _forwardEventToCurrentLayer(event: any): void;
    _onanyclick({ srcEvent }: any): void;
    _onkeyup({ srcEvent }: {
        srcEvent: KeyboardEvent;
    }): void;
    _onpanstart(event: any): void;
    _onpanmove(event: any): void;
    _onpanend({ srcEvent }: any): void;
    _onpointermove(event: any): void;
    getPicks(screenCoords: [number, number]): {
        color: Uint8Array | null;
        layer: import("@deck.gl/core").Layer | null;
        sourceLayer?: import("@deck.gl/core").Layer | null;
        viewport?: import("@deck.gl/core").Viewport;
        index: number;
        picked: boolean;
        object?: any;
        x: number;
        y: number;
        pixel?: [number, number];
        coordinate?: number[];
        devicePixel?: [number, number];
        pixelRatio: number;
    }[];
    getScreenCoords(pointerEvent: any): Position;
    getMapCoords(screenCoords: Position): Position;
}
//# sourceMappingURL=editable-layer.d.ts.map