// deck.gl-community
// SPDX-License-Identifier: MIT
// Copyright (c) vis.gl contributors
import { NebulaLayer } from "../nebula-layer.js";
import { toDeckColor } from "../../utils/utils.js";
import { DeckCache } from "../deck-renderer/deck-cache.js";
import { JunctionScatterplotLayer } from "../../editable-layers/junction-scatterplot-layer.js";
export class JunctionsLayer extends NebulaLayer {
    deckCache;
    constructor(config) {
        super(config);
        this.deckCache = new DeckCache(config.getData, (data) => config.toNebulaFeature(data));
        this.enablePicking = true;
    }
    render({ nebula }) {
        const defaultColor = [0x0, 0x0, 0x0, 0xff];
        const { objects, updateTrigger } = this.deckCache;
        return new JunctionScatterplotLayer({
            id: `junctions-${this.id}`,
            data: objects,
            opacity: 1,
            pickable: true,
            getPosition: (nf) => nf.geoJson.geometry.coordinates,
            getFillColor: (nf) => toDeckColor(nf.style.fillColor) || defaultColor,
            getStrokeColor: (nf) => toDeckColor(nf.style.outlineColor) || toDeckColor(nf.style.fillColor) || defaultColor,
            getRadius: (nf) => nf.style.pointRadiusMeters + nf.style.outlineRadiusMeters || 1,
            getInnerRadius: (nf) => nf.style.pointRadiusMeters || 0.5,
            parameters: {
                depthCompare: 'always'
            },
            updateTriggers: { all: updateTrigger },
            // @ts-expect-error TODO
            nebulaLayer: this
        });
    }
}
