// deck.gl-community
// SPDX-License-Identifier: MIT
// Copyright (c) vis.gl contributors
import { TextLayer } from '@deck.gl/layers';
import { NebulaLayer } from "../nebula-layer.js";
import { toDeckColor } from "../../utils/utils.js";
import { PROJECTED_PIXEL_SIZE_MULTIPLIER } from "../constants.js";
import { DeckCache } from "../deck-renderer/deck-cache.js";
export class TextsLayer extends NebulaLayer {
    deckCache;
    constructor(config) {
        super(config);
        this.deckCache = new DeckCache(config.getData, (data) => config.toNebulaFeature(data));
    }
    render({ nebula }) {
        const defaultColor = [0x0, 0x0, 0x0, 0xff];
        const { objects, updateTrigger } = this.deckCache;
        const { zoom } = nebula.props.viewport;
        return new TextLayer({
            id: `texts-${this.id}`,
            data: objects,
            opacity: 1,
            fp64: false,
            pickable: false,
            getText: (nf) => nf.style.text,
            getPosition: (nf) => nf.geoJson.geometry.coordinates,
            getColor: (nf) => toDeckColor(nf.style.fillColor) || defaultColor,
            // TODO: layer should offer option to scale with zoom
            sizeScale: 1 / Math.pow(2, 20 - zoom),
            getSize: PROJECTED_PIXEL_SIZE_MULTIPLIER,
            updateTriggers: { all: updateTrigger },
            nebulaLayer: this
        });
    }
}
