import { ModeHandler } from "./mode-handler.js";
// TODO edit-modes: delete handlers once EditMode fully implemented
export class CompositeModeHandler extends ModeHandler {
    handlers;
    options;
    constructor(handlers, options = {}) {
        super();
        this.handlers = handlers;
        this.options = options;
    }
    _coalesce(callback, resultEval = null) {
        let result;
        for (let i = 0; i < this.handlers.length; i++) {
            // eslint-disable-next-line callback-return
            result = callback(this.handlers[i]);
            if (resultEval ? resultEval(result) : result) {
                break;
            }
        }
        return result;
    }
    setFeatureCollection(featureCollection) {
        this.handlers.forEach((handler) => handler.setFeatureCollection(featureCollection));
    }
    setModeConfig(modeConfig) {
        this.handlers.forEach((handler) => handler.setModeConfig(modeConfig));
    }
    setSelectedFeatureIndexes(indexes) {
        this.handlers.forEach((handler) => handler.setSelectedFeatureIndexes(indexes));
    }
    handleClick(event) {
        return this._coalesce((handler) => handler.handleClick(event));
    }
    handlePointerMove(event) {
        return this._coalesce((handler) => handler.handlePointerMove(event), (result) => result && Boolean(result.editAction)); // TODO
    }
    handleStartDragging(event) {
        return this._coalesce((handler) => handler.handleStartDragging(event));
    }
    handleStopDragging(event) {
        return this._coalesce((handler) => handler.handleStopDragging(event));
    }
    getTentativeFeature() {
        return this._coalesce((handler) => handler.getTentativeFeature());
    }
    getEditHandles(picks, mapCoords) {
        // TODO: Combine the handles *BUT* make sure if none of the results have
        // changed to return the same object so that "editHandles !== this.state.editHandles"
        // in editable-geojson-layer works.
        return this._coalesce((handler) => handler.getEditHandles(picks, mapCoords), (handles) => Array.isArray(handles) && handles.length > 0); // TODO
    }
    getCursor({ isDragging }) {
        return this._coalesce((handler) => handler.getCursor({ isDragging })); // TODO
    }
}
