// deck.gl-community
// SPDX-License-Identifier: MIT
// Copyright (c) vis.gl contributors
import turfCentroid from '@turf/centroid';
import turfBearing from '@turf/bearing';
import turfTransformRotate from '@turf/transform-rotate';
import { ModeHandler } from "./mode-handler.js";
// TODO edit-modes: delete handlers once EditMode fully implemented
export class RotateHandler extends ModeHandler {
    _isRotatable = undefined;
    _geometryBeingRotated;
    handlePointerMove(event) {
        let editAction = null;
        this._isRotatable = Boolean(this._geometryBeingRotated) || this.isSelectionPicked(event.picks);
        if (!this._isRotatable || !event.pointerDownMapCoords) {
            // Nothing to do
            return { editAction: null, cancelMapPan: false };
        }
        if (event.isDragging && this._geometryBeingRotated) {
            // Rotate the geometry
            editAction = this.getRotateAction(event.pointerDownMapCoords, event.mapCoords, 'rotating');
        }
        return { editAction, cancelMapPan: true };
    }
    handleStartDragging(event) {
        if (!this._isRotatable) {
            return null;
        }
        this._geometryBeingRotated = this.getSelectedFeaturesAsFeatureCollection();
        return null;
    }
    handleStopDragging(event) {
        let editAction = null;
        if (this._geometryBeingRotated) {
            // Rotate the geometry
            editAction = this.getRotateAction(event.pointerDownMapCoords, event.mapCoords, 'rotated');
            this._geometryBeingRotated = null;
        }
        return editAction;
    }
    getCursor({ isDragging }) {
        if (this._isRotatable) {
            // TODO: look at doing SVG cursors to get a better "rotate" cursor
            return 'move';
        }
        return isDragging ? 'grabbing' : 'grab';
    }
    getRotateAction(startDragPoint, currentPoint, editType) {
        const startPosition = startDragPoint;
        // @ts-expect-error turf types diff
        const centroid = turfCentroid(this._geometryBeingRotated);
        // @ts-expect-error turf types diff
        const angle = getRotationAngle(centroid, startPosition, currentPoint);
        // @ts-expect-error turf type diff
        const rotatedFeatures = turfTransformRotate(
        // @ts-expect-error turf type diff
        this._geometryBeingRotated, angle);
        let updatedData = this.getImmutableFeatureCollection();
        const selectedIndexes = this.getSelectedFeatureIndexes();
        for (let i = 0; i < selectedIndexes.length; i++) {
            const selectedIndex = selectedIndexes[i];
            const movedFeature = rotatedFeatures.features[i];
            updatedData = updatedData.replaceGeometry(selectedIndex, movedFeature.geometry);
        }
        return {
            updatedData: updatedData.getObject(),
            editType,
            featureIndexes: selectedIndexes,
            editContext: null
        };
    }
}
function getRotationAngle(centroid, startDragPoint, currentPoint) {
    const bearing1 = turfBearing(centroid, startDragPoint);
    const bearing2 = turfBearing(centroid, currentPoint);
    return bearing2 - bearing1;
}
