// deck.gl-community
// SPDX-License-Identifier: MIT
// Copyright (c) vis.gl contributors
import turfCentroid from '@turf/centroid';
import turfDistance from '@turf/distance';
import turfTransformScale from '@turf/transform-scale';
import { ModeHandler } from "./mode-handler.js";
// TODO edit-modes: delete handlers once EditMode fully implemented
export class ScaleHandler extends ModeHandler {
    _isScalable = undefined;
    _geometryBeingScaled;
    handlePointerMove(event) {
        let editAction = null;
        this._isScalable = Boolean(this._geometryBeingScaled) || this.isSelectionPicked(event.picks);
        if (!this._isScalable || !event.pointerDownMapCoords) {
            // Nothing to do
            return { editAction: null, cancelMapPan: false };
        }
        if (event.isDragging && this._geometryBeingScaled) {
            // Scale the geometry
            editAction = this.getScaleAction(event.pointerDownMapCoords, event.mapCoords, 'scaling');
        }
        return { editAction, cancelMapPan: true };
    }
    handleStartDragging(event) {
        if (!this._isScalable) {
            return null;
        }
        this._geometryBeingScaled = this.getSelectedFeaturesAsFeatureCollection();
        return null;
    }
    handleStopDragging(event) {
        let editAction = null;
        if (this._geometryBeingScaled) {
            // Scale the geometry
            editAction = this.getScaleAction(event.pointerDownMapCoords, event.mapCoords, 'scaled');
            this._geometryBeingScaled = null;
        }
        return editAction;
    }
    getCursor({ isDragging }) {
        if (this._isScalable) {
            // TODO: look at doing SVG cursors to get a better "scale" cursor
            return 'move';
        }
        return isDragging ? 'grabbing' : 'grab';
    }
    getScaleAction(startDragPoint, currentPoint, editType) {
        const startPosition = startDragPoint;
        // @ts-expect-error turf types diff
        const centroid = turfCentroid(this._geometryBeingScaled);
        // @ts-expect-error turf types diff
        const factor = getScaleFactor(centroid, startPosition, currentPoint);
        // @ts-expect-error turf type diff
        const scaledFeatures = turfTransformScale(
        // @ts-expect-error turf type diff
        this._geometryBeingScaled, factor, {
            origin: centroid
        });
        let updatedData = this.getImmutableFeatureCollection();
        const selectedIndexes = this.getSelectedFeatureIndexes();
        for (let i = 0; i < selectedIndexes.length; i++) {
            const selectedIndex = selectedIndexes[i];
            const movedFeature = scaledFeatures.features[i];
            updatedData = updatedData.replaceGeometry(selectedIndex, movedFeature.geometry);
        }
        return {
            updatedData: updatedData.getObject(),
            editType,
            featureIndexes: selectedIndexes,
            editContext: null
        };
    }
}
function getScaleFactor(centroid, startDragPoint, currentPoint) {
    const startDistance = turfDistance(centroid, startDragPoint);
    const endDistance = turfDistance(centroid, currentPoint);
    return endDistance / startDistance;
}
