// deck.gl-community
// SPDX-License-Identifier: MIT
// Copyright (c) vis.gl contributors
import turfBearing from '@turf/bearing';
import turfDistance from '@turf/distance';
import turfTransformTranslate from '@turf/transform-translate';
import { point } from '@turf/helpers';
import { ModeHandler } from "./mode-handler.js";
// TODO edit-modes: delete handlers once EditMode fully implemented
export class TranslateHandler extends ModeHandler {
    _geometryBeforeTranslate;
    _isTranslatable = undefined;
    handlePointerMove(event) {
        let editAction = null;
        this._isTranslatable =
            Boolean(this._geometryBeforeTranslate) || this.isSelectionPicked(event.picks);
        if (!this._isTranslatable || !event.pointerDownMapCoords) {
            // Nothing to do
            return { editAction: null, cancelMapPan: false };
        }
        if (event.isDragging && this._geometryBeforeTranslate) {
            // Translate the geometry
            editAction = this.getTranslateAction(event.pointerDownMapCoords, event.mapCoords, 'translating');
        }
        return { editAction, cancelMapPan: true };
    }
    handleStartDragging(event) {
        if (!this._isTranslatable) {
            return null;
        }
        this._geometryBeforeTranslate = this.getSelectedFeaturesAsFeatureCollection();
        return null;
    }
    handleStopDragging(event) {
        let editAction = null;
        if (this._geometryBeforeTranslate) {
            // Translate the geometry
            editAction = this.getTranslateAction(event.pointerDownMapCoords, event.mapCoords, 'translated');
            this._geometryBeforeTranslate = null;
        }
        return editAction;
    }
    getCursor({ isDragging }) {
        if (this._isTranslatable) {
            return 'move';
        }
        return isDragging ? 'grabbing' : 'grab';
    }
    getTranslateAction(startDragPoint, currentPoint, editType) {
        if (!this._geometryBeforeTranslate) {
            return null;
        }
        const p1 = point(startDragPoint);
        const p2 = point(currentPoint);
        const distanceMoved = turfDistance(p1, p2);
        const direction = turfBearing(p1, p2);
        // @ts-expect-error turf type diff
        const movedFeatures = turfTransformTranslate(
        // @ts-expect-error turf type diff
        this._geometryBeforeTranslate, distanceMoved, direction);
        let updatedData = this.getImmutableFeatureCollection();
        const selectedIndexes = this.getSelectedFeatureIndexes();
        for (let i = 0; i < selectedIndexes.length; i++) {
            const selectedIndex = selectedIndexes[i];
            const movedFeature = movedFeatures.features[i];
            updatedData = updatedData.replaceGeometry(selectedIndex, movedFeature.geometry);
        }
        return {
            updatedData: updatedData.getObject(),
            editType,
            featureIndexes: selectedIndexes,
            editContext: null
        };
    }
}
