// deck.gl-community
// SPDX-License-Identifier: MIT
// Copyright (c) vis.gl contributors

import {NebulaLayer} from '../nebula-layer';
import {toDeckColor} from '../../utils/utils';
import {DeckCache} from '../deck-renderer/deck-cache';
import {JunctionScatterplotLayer} from '../../editable-layers/junction-scatterplot-layer';

export class JunctionsLayer extends NebulaLayer {
  deckCache: DeckCache<any, any>;

  constructor(config: Record<string, any>) {
    super(config);
    this.deckCache = new DeckCache(config.getData, (data) => config.toNebulaFeature(data));
    this.enablePicking = true;
  }

  render({nebula}: Record<string, any>) {
    const defaultColor: [number, number, number, number] = [0x0, 0x0, 0x0, 0xff];
    const {objects, updateTrigger} = this.deckCache;

    return new JunctionScatterplotLayer({
      id: `junctions-${this.id}`,
      data: objects,
      opacity: 1,
      pickable: true,
      getPosition: (nf: any) => nf.geoJson.geometry.coordinates,
      getFillColor: (nf: any) => toDeckColor(nf.style.fillColor) || defaultColor,
      getStrokeColor: (nf: any) =>
        toDeckColor(nf.style.outlineColor) || toDeckColor(nf.style.fillColor) || defaultColor,
      getRadius: (nf: any) => nf.style.pointRadiusMeters + nf.style.outlineRadiusMeters || 1,
      getInnerRadius: (nf: any) => nf.style.pointRadiusMeters || 0.5,
      parameters: {
        depthCompare: 'always'
      },

      updateTriggers: {all: updateTrigger},

      // @ts-expect-error TODO
      nebulaLayer: this
    });
  }
}
